// ---------------------------------------------------------------------------
// FormEditConnection.c
// Contains PalmOS specific code, for frmEditConnection form
// 
// Project: WAPUniverse for PalmOS
// Copyright  1999-2000 Filip Onkelinx
//
// http://www.wapuniverse.com/
// filip@onkelinx.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
//
// 
// $Workfile: formEditConnection.c $  
// $Author: wapuniverse $  
// $Date: 2000/11/11 20:51:09 $     
// $Revision: 1.7 $
// 
// $Header: /cvsroot/wapuniverse/wapuniverse/src/formEditConnection.c,v 1.7 2000/11/11 20:51:09 wapuniverse Exp $
// 
// -------------------------------------------------------------------------------
#include    <PalmOS.h>
#include    <SysEvtMgr.h>
#include 	"WAPUniverse.h"
#include    "formConnectionList.h"
#include    "formUrlList.h"
#include    "dbConn.h"
#include 	"PalmUtils.h"
#include    "formEditConnection.h"
#include 	"../res/WAPUniverse_res.h"
#ifdef __GNUC__
#include "callbacks.h"
#endif

static Boolean ButtonConnectionSettingsDone_OH(EventPtr event, GlobalsType *g) SEC_1;
static Boolean ButtonConnectionSettingsDelete_OH(EventPtr event, GlobalsType *g) SEC_1;
static void ConnectionDetailsInit (GlobalsType *g) SEC_1;
static UInt16 ConnectionDetailsApply (GlobalsType *g) SEC_1;

static void ConnectionDetailsInit (GlobalsType *g)
{
  UInt16            		attr;
  dbConnPackedConnection*	pconn;
  MemHandle        			rechand;
  Int16             		seekAmount = g->DbConnCurrentRecord;
  UInt16            		index = 0;

  // must do seek to skip over secret records
  DmSeekRecordInCategory (g->DbConnDb, &index, seekAmount, dmSeekForward, dmAllCategories);

  // Get the secret and category attributes of the current record.
  DmRecordInfo (g->DbConnDb, index, &attr, NULL, NULL);
//  gRecordCategory = attr & dmRecAttrCategoryMask;

  rechand = DmQueryRecord (g->DbConnDb, index);
  pconn = MemHandleLock (rechand);
  dbConnUnPackConnection (&(g->CurrentConnection), pconn);

  SetFieldFromStr(g->CurrentConnection.name , fldConnectionName);
  SetFieldFromStr(g->CurrentConnection.ipaddress , fldIPAddress);
  
  MemHandleUnlock (rechand);

}

static UInt16 ConnectionDetailsApply (GlobalsType *g)
{
  UInt16            attr;
  UInt16            updateCode = 0;
  dbConnConnection 	tConn;
  MemHandle        	currec;
  FormPtr         	frm;
  FieldPtr        	ipPtr;
  Int16             seekAmount = g->DbConnCurrentRecord;
  UInt16            index = 0;

  // must do seek to skip over secret records
  DmSeekRecordInCategory (g->DbConnDb, &index, seekAmount, dmSeekForward, dmAllCategories);

  // Get the secret and category attributes of the current record.
  DmRecordInfo (g->DbConnDb, index, &attr, NULL, NULL);

  frm = FrmGetFormPtr (frmEditConnection);
  ipPtr = (FieldPtr) (FrmGetObjectPtr (frm, (FrmGetObjectIndex (frm, fldConnectionName))));
  if (FldGetTextPtr (ipPtr) != NULL)
    StrCopy (tConn.name, FldGetTextPtr (ipPtr));
  ipPtr = (FieldPtr) (FrmGetObjectPtr (frm, (FrmGetObjectIndex (frm, fldIPAddress))));
  if (FldGetTextPtr (ipPtr) != NULL)
    StrCopy (tConn.ipaddress, FldGetTextPtr (ipPtr));
  tConn.security = 'N';
  tConn.bearer = 'C';
  tConn.connectionType = 'L';
  currec = DmGetRecord (g->DbConnDb, index);
  dbConnPackConnection (&tConn, currec);
  DmReleaseRecord (g->DbConnDb, index, true);
  dbConnSortRecord (g->DbConnDb, &index);

  return updateCode;
}


/**----------------------------------**/
/** Form Event Handler for FormEditSettings**/
/**----------------------------------**/

/****************************************************/
/* 
   Function: Boolean FormEditSettings_EH(EventPtr event);
   Description: Main Form Event Handler for FormEditSettings
 */
/****************************************************/


/* Form Event Handler */
Boolean ehFormEditConnection(EventPtr event)
{
    Boolean handled = false;
	GlobalsType *g;
	
#ifdef __GNUC__
    CALLBACK_PROLOGUE
#endif

	FtrGet(wuAppType, ftrGlobals, (UInt32 *)&g);
    switch(event->eType) {

        case ctlSelectEvent:
            if (event->data.ctlSelect.controlID == buttonConnectionSettingsDone) {
                handled = ButtonConnectionSettingsDone_OH(event,g); }
            if (event->data.ctlSelect.controlID == buttonConnectionSettingsDelete) {
                handled = ButtonConnectionSettingsDelete_OH(event,g); }
            break;

        case ctlRepeatEvent:
            break;

        case tblSelectEvent:
            break;

        case lstSelectEvent:
        case popSelectEvent:
            break;

        case sclEnterEvent:
            break;

        case frmOpenEvent:
           ConnectionDetailsInit(g);
           FrmDrawForm(FrmGetActiveForm());
           handled = true;
           break;
	default:
	   break;


           }
#ifdef __GNUC__
    CALLBACK_EPILOGUE
#endif
    return handled;
}


/* Item Handler Functions Here */

/**--------------------------------------**/
/** Form Object Handler Functions for FormEditSettings **/
/**--------------------------------------**/

/****************************************************/
/* 
   Function: Int16 ButtonConnectionSettingsDone_OH(EventPtr event);
   Description: Button Object Handler for the FormEditSettings Form
 */
/****************************************************/

static Boolean ButtonConnectionSettingsDone_OH(EventPtr event, GlobalsType *g)
{
    ConnectionDetailsApply (g);
    FrmCloseAllForms ();
    g->CurrentView = frmConnectionList;

    FrmGotoForm (g->CurrentView);
	return(true);
}


/****************************************************/
/* 
   Function: Int16 ButtonConnectionSettingsDelete_OH(EventPtr event);
   Description: Button Object Handler for the FormEditSettings Form
 */
/****************************************************/

static Boolean ButtonConnectionSettingsDelete_OH(EventPtr event, GlobalsType *g)
{
    // The delete button was pressed.  Delete the current record.
    if ( dbConnDeleteCurrentRecord (g))
    {
       // Delete was completed.  Close the details and the edit forms.
       FrmCloseAllForms ();

       // Go to the main form.
	   g->CurrentView = frmConnectionList;
       FrmGotoForm (g->CurrentView);
    }
	return(true);
}


